@@ -24,8 +24,8 @@ import logging as log
 import requests
 import simplejson as json
 
-from qubellclient.private.platform import QubellPlatform
-from qubellclient.private import exceptions
+from qubell.api.private.platform import QubellPlatform
+from qubell.api.private import exceptions
 
 
 class Organization(QubellPlatform):
