@@ -26,7 +26,7 @@ import simplejson as json
 
 import application
 from qubell.api.private import exceptions
-from qubellclient.tools import retry
+from qubell.api.tools import retry
 
 
 class Instance(application.Application):
